@@ -1,6 +1,3 @@
-/* $Id$ $Revision$ */
-/* vim:set shiftwidth=4 ts=8: */
-
 /*************************************************************************
  * Copyright (c) 2011 AT&T Intellectual Property 
  * All rights reserved. This program and the accompanying materials
@@ -8,7 +5,7 @@
  * which accompanies this distribution, and is available at
  * http://www.eclipse.org/legal/epl-v10.html
  *
- * Contributors: See CVS logs. Details at http://www.graphviz.org/
+ * Contributors: Details at https://graphviz.org
  *************************************************************************/
 
 /* Lefteris Koutsofios - AT&T Bell Laboratories */
@@ -18,6 +15,7 @@
 #include <stdio.h>
 #include <string.h>
 #include <stdlib.h>
+#include <shellapi.h>
 #include <sys/types.h>
 #include <sys/stat.h>
 
@@ -41,6 +39,8 @@ int APIENTRY WinMain (
     char cmd[256];
     char *path;
     char *s;
+    int argc;
+    LPWSTR *argv;
 
     ZeroMemory (&si, sizeof(si));
     si.cb = sizeof(si);
@@ -56,16 +56,19 @@ int APIENTRY WinMain (
         if (!(path = buildpath ("lefty")))
             exit (1);
     }
+    argv = CommandLineToArgvW(lpCmdLine, &argc);
+    if (argc == 1 && strcmp(argv[0], "-?") == 0) {
+        fprintf(stderr, "usage: dotty [-V] [-lm (sync|async)] [-el (0|1)] <filename>\n");
+        exit(0);
+    }
     if (lpCmdLine[0] == 0)
-        sprintf (
-	    cmd, "%s -e \"load('dotty.lefty');%sdotty.init();dotty.createviewandgraph(null,'file',null,null);txtview('off');\"",
-	    path, lneato
-        );
+        snprintf(cmd, sizeof(cmd), "%s -e \"load('dotty.lefty');%sdotty.init();"
+                 "dotty.createviewandgraph(null,'file',null,null);"
+                 "txtview('off');\"", path, lneato);
     else
-        sprintf (
-	    cmd, "%s -e \"load('dotty.lefty');%sdotty.init();dotty.createviewandgraph('%Ns','file',null,null);txtview('off');\"",
-            path, lneato, lpCmdLine
-        );
+        snprintf(cmd, sizeof(cmd), "%s -e \"load('dotty.lefty');%sdotty.init();"
+                 "dotty.createviewandgraph('%Ns','file',null,null);"
+                 "txtview('off');\"", path, lneato, lpCmdLine);
 
     CreateProcess (
         NULL,   // No module name (use command line). 
