@@ -30,19 +30,27 @@
    This special exception was added by the Free Software Foundation in
    version 2.2 of Bison.  */
 
-#ifndef YY_YY_Y_TAB_H_INCLUDED
-# define YY_YY_Y_TAB_H_INCLUDED
+#ifndef YY_AAG_GRAMMAR_H_INCLUDED
+# define YY_AAG_GRAMMAR_H_INCLUDED
 /* Debug traces.  */
-#ifndef YYDEBUG
-# define YYDEBUG 0
-#endif
+#ifndef AAGDEBUG
+# if defined YYDEBUG
 #if YYDEBUG
+#   define AAGDEBUG 1
+#  else
+#   define AAGDEBUG 0
+#  endif
+# else /* ! defined YYDEBUG */
+#  define AAGDEBUG 0
+# endif /* ! defined YYDEBUG */
+#endif  /* ! defined AAGDEBUG */
+#if AAGDEBUG
 extern int aagdebug;
 #endif
 
 /* Token type.  */
-#ifndef YYTOKENTYPE
-# define YYTOKENTYPE
+#ifndef AAGTOKENTYPE
+# define AAGTOKENTYPE
   enum aagtokentype
   {
     T_graph = 258,
@@ -72,27 +80,27 @@ extern int aagdebug;
 #define T_qatom 268
 
 /* Value type.  */
-#if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
+#if ! defined AAGSTYPE && ! defined AAGSTYPE_IS_DECLARED
 
-union YYSTYPE
+union AAGSTYPE
 {
-#line 82 "../../lib/cgraph/grammar.y" /* yacc.c:1909  */
+#line 89 "../../lib/cgraph/grammar.y" /* yacc.c:1909  */
 
 			int				i;
 			char			*str;
 			struct Agnode_s	*n;
 
-#line 86 "y.tab.h" /* yacc.c:1909  */
+#line 94 "grammar.h" /* yacc.c:1909  */
 };
 
-typedef union YYSTYPE YYSTYPE;
-# define YYSTYPE_IS_TRIVIAL 1
-# define YYSTYPE_IS_DECLARED 1
+typedef union AAGSTYPE AAGSTYPE;
+# define AAGSTYPE_IS_TRIVIAL 1
+# define AAGSTYPE_IS_DECLARED 1
 #endif
 
 
-extern YYSTYPE aaglval;
+extern AAGSTYPE aaglval;
 
 int aagparse (void);
 
-#endif /* !YY_YY_Y_TAB_H_INCLUDED  */
+#endif /* !YY_AAG_GRAMMAR_H_INCLUDED  */
