@@ -15,11 +15,11 @@
 extern "C" {
 #endif
 
-/*visual studio*/
 #if defined(_WIN32) && !defined(LAB_GAMUT_EXPORTS)
-#define extern __declspec(dllimport)
+#define EXTERN __declspec(dllimport)
+#else
+#define EXTERN /* nothing */
 #endif
-/*end visual studio*/
 
 /** lookup table for the visible spectrum of the CIELAB color space
  *
@@ -31,10 +31,10 @@ extern "C" {
  * More information about CIELAB:
  *   https://en.wikipedia.org/wiki/CIELAB_color_space
  */
-extern const signed char lab_gamut_data[];
-extern int lab_gamut_data_size;
+EXTERN extern const signed char lab_gamut_data[];
+EXTERN extern int lab_gamut_data_size;
 
-#undef extern
+#undef EXTERN
 
 #ifdef __cplusplus
 }
