@@ -32,12 +32,20 @@
    This special exception was added by the Free Software Foundation in
    version 2.2 of Bison.  */
 
-#ifndef EX_EX_Y_TAB_H_INCLUDED
-# define EX_EX_Y_TAB_H_INCLUDED
+#ifndef YY_EX_Y_TAB_H_INCLUDED
+# define YY_EX_Y_TAB_H_INCLUDED
 /* Debug traces.  */
 #ifndef EXDEBUG
-# define EXDEBUG 1
-#endif
+# if defined YYDEBUG
+#if YYDEBUG
+#   define EXDEBUG 1
+#  else
+#   define EXDEBUG 0
+#  endif
+# else /* ! defined YYDEBUG */
+#  define EXDEBUG 1
+# endif /* ! defined YYDEBUG */
+#endif  /* ! defined EXDEBUG */
 #if EXDEBUG
 extern int exdebug;
 #endif
@@ -214,7 +222,7 @@ extern int exdebug;
 
 union EXSTYPE
 {
-#line 39 "../../lib/expr/exparse.y" /* yacc.c:1909  */
+#line 49 "../../lib/expr/exparse.y" /* yacc.c:1909  */
 
 	struct Exnode_s*expr;
 	double		floating;
@@ -226,7 +234,7 @@ union EXSTYPE
 	void*		user;
 	struct Exbuf_s*	buffer;
 
-#line 228 "y.tab.h" /* yacc.c:1909  */
+#line 236 "y.tab.h" /* yacc.c:1909  */
 };
 
 typedef union EXSTYPE EXSTYPE;
@@ -239,5 +247,5 @@ extern EXSTYPE exlval;
 
 int exparse (void);
 
-#endif /* !EX_EX_Y_TAB_H_INCLUDED  */
+#endif /* !YY_EX_Y_TAB_H_INCLUDED  */
 #endif /* _EXPARSE_H */
