@@ -30,20 +30,28 @@
    This special exception was added by the Free Software Foundation in
    version 2.2 of Bison.  */
 
-#ifndef YY_YY_Y_TAB_H_INCLUDED
-# define YY_YY_Y_TAB_H_INCLUDED
+#ifndef YY_EX_Y_TAB_H_INCLUDED
+# define YY_EX_Y_TAB_H_INCLUDED
 /* Debug traces.  */
-#ifndef YYDEBUG
-# define YYDEBUG 1
-#endif
+#ifndef EXDEBUG
+# if defined YYDEBUG
 #if YYDEBUG
-extern int yydebug;
+#   define EXDEBUG 1
+#  else
+#   define EXDEBUG 0
+#  endif
+# else /* ! defined YYDEBUG */
+#  define EXDEBUG 1
+# endif /* ! defined YYDEBUG */
+#endif  /* ! defined EXDEBUG */
+#if EXDEBUG
+extern int exdebug;
 #endif
 
 /* Token type.  */
-#ifndef YYTOKENTYPE
-# define YYTOKENTYPE
-  enum yytokentype
+#ifndef EXTOKENTYPE
+# define EXTOKENTYPE
+  enum extokentype
   {
     MINTOKEN = 258,
     INTEGER = 259,
@@ -208,11 +216,11 @@ extern int yydebug;
 #define MAXTOKEN 336
 
 /* Value type.  */
-#if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
+#if ! defined EXSTYPE && ! defined EXSTYPE_IS_DECLARED
 
-union YYSTYPE
+union EXSTYPE
 {
-#line 39 "../../lib/expr/exparse.y" /* yacc.c:1909  */
+#line 49 "../../lib/expr/exparse.y" /* yacc.c:1909  */
 
 	struct Exnode_s*expr;
 	double		floating;
@@ -224,17 +232,17 @@ union YYSTYPE
 	void*		user;
 	struct Exbuf_s*	buffer;
 
-#line 228 "y.tab.h" /* yacc.c:1909  */
+#line 236 "y.tab.h" /* yacc.c:1909  */
 };
 
-typedef union YYSTYPE YYSTYPE;
-# define YYSTYPE_IS_TRIVIAL 1
-# define YYSTYPE_IS_DECLARED 1
+typedef union EXSTYPE EXSTYPE;
+# define EXSTYPE_IS_TRIVIAL 1
+# define EXSTYPE_IS_DECLARED 1
 #endif
 
 
-extern YYSTYPE yylval;
+extern EXSTYPE exlval;
 
-int yyparse (void);
+int exparse (void);
 
-#endif /* !YY_YY_Y_TAB_H_INCLUDED  */
+#endif /* !YY_EX_Y_TAB_H_INCLUDED  */
