@@ -1,6 +1,3 @@
-/* $Id$ $Revision$ */
-/* vim:set shiftwidth=4 ts=8: */
-
 /*************************************************************************
  * Copyright (c) 2011 AT&T Intellectual Property 
  * All rights reserved. This program and the accompanying materials
@@ -8,7 +5,7 @@
  * which accompanies this distribution, and is available at
  * http://www.eclipse.org/legal/epl-v10.html
  *
- * Contributors: See CVS logs. Details at http://www.graphviz.org/
+ * Contributors: Details at https://graphviz.org
  *************************************************************************/
 
 
@@ -19,9 +16,9 @@
 
 #include <math.h>
 #include <assert.h>
-#include "render.h"
-#include "pack.h"
-#include "pointset.h"
+#include <common/render.h>
+#include <pack/pack.h>
+#include <common/pointset.h>
 #include <assert.h>
 
 #define strneq(a,b,n)		(!strncmp(a,b,n))
@@ -98,8 +95,8 @@ static int computeStep(int ng, boxf* bbs, unsigned int margin)
  */
 static int cmpf(const void *X, const void *Y)
 {
-    ginfo *x = *(ginfo **) X;
-    ginfo *y = *(ginfo **) Y;
+    const ginfo *x = *(ginfo *const *) X;
+    const ginfo *y = *(ginfo *const *) Y;
     /* flip order to get descending array */
     return (y->perim - x->perim);
 }
@@ -117,10 +114,10 @@ static void fillLine(pointf p, pointf q, PointSet * ps)
     int d, x, y, ax, ay, sx, sy, dx, dy;
 
     dx = x2 - x1;
-    ax = ABS(dx) << 1;
+    ax = abs(dx) << 1;
     sx = SGN(dx);
     dy = y2 - y1;
-    ay = ABS(dy) << 1;
+    ay = abs(dy) << 1;
     sy = SGN(dy);
 
 /* fprintf (stderr, "fillLine %d %d - %d %d\n", x1,y1,x2,y2); */
@@ -569,8 +566,8 @@ static packval_t* userVals;
  */
 static int ucmpf(const void *X, const void *Y)
 {
-    ainfo* x = *(ainfo **) X;
-    ainfo* y = *(ainfo **) Y;
+    const ainfo* x = *(ainfo *const *) X;
+    const ainfo* y = *(ainfo *const *) Y;
 
     int dX = userVals[x->index];
     int dY = userVals[y->index];
@@ -584,15 +581,8 @@ static int ucmpf(const void *X, const void *Y)
  */
 static int acmpf(const void *X, const void *Y)
 {
-    ainfo* x = *(ainfo **) X;
-    ainfo* y = *(ainfo **) Y;
-#if 0
-    if (x->height < y->height) return 1;
-    else if (x->height > y->height) return -1;
-    else if (x->width < y->width) return 1;
-    else if (x->width > y->width) return -1;
-    else return 0;
-#endif
+    const ainfo* x = *(ainfo *const *) X;
+    const ainfo* y = *(ainfo *const *) Y;
     double dX = x->height + x->width; 
     double dY = y->height + y->width; 
     if (dX < dY) return 1;
@@ -1312,12 +1302,6 @@ parsePackModeInfo(char* p, pack_mode dflt, pack_info* pinfo)
 		    pinfo->aspect = 1;
 	    }
 	    break;
-#ifdef NOT_IMPLEMENTED
-	case 'b':
-	    if (streq(p, "bisect"))
-		pinfo->mode = l_bisect;
-	    break;
-#endif
 	case 'c':
 	    if (streq(p, "cluster"))
 		pinfo->mode = l_clust;
@@ -1326,22 +1310,10 @@ parsePackModeInfo(char* p, pack_mode dflt, pack_info* pinfo)
 	    if (streq(p, "graph"))
 		pinfo->mode = l_graph;
 	    break;
-#ifdef NOT_IMPLEMENTED
-	case 'h':
-	    if (streq(p, "hull"))
-		pinfo->mode = l_hull;
-	    break;
-#endif
 	case 'n':
 	    if (streq(p, "node"))
 		pinfo->mode = l_node;
 	    break;
-#ifdef NOT_IMPLEMENTED
-	case 't':
-	    if (streq(p, "tile"))
-		pinfo->mode = l_tile;
-	    break;
-#endif
 	}
     }
 
@@ -1409,5 +1381,3 @@ getPackInfo(Agraph_t * g, pack_mode dflt, int dfltMargin, pack_info* pinfo)
 
     return pinfo->mode;
 }
-
-
