@@ -1,6 +1,3 @@
-/* $Id$ $Revision$ */
-/* vim:set shiftwidth=4 ts=8: */
-
 /*************************************************************************
  * Copyright (c) 2011 AT&T Intellectual Property 
  * All rights reserved. This program and the accompanying materials
@@ -8,25 +5,18 @@
  * which accompanies this distribution, and is available at
  * http://www.eclipse.org/legal/epl-v10.html
  *
- * Contributors: See CVS logs. Details at http://www.graphviz.org/
+ * Contributors: Details at https://graphviz.org
  *************************************************************************/
 
-#include	"sfhdr.h"
+#include	<sfio/sfhdr.h>
+#include	<stddef.h>
 
 /*	Push back one byte to a given SF_READ stream
 **
 **	Written by Kiem-Phong Vo.
 */
-#if __STD_C
-static int _uexcept(reg Sfio_t * f, reg int type, Void_t * val,
-		    reg Sfdisc_t * disc)
-#else
-static int _uexcept(f, type, val, disc)
-reg Sfio_t *f;
-reg int type;
-Void_t *val;
-reg Sfdisc_t *disc;
-#endif
+static int _uexcept(Sfio_t * f, int type, void * val,
+		    Sfdisc_t * disc)
 {
     NOTUSED(val);
 
@@ -36,20 +26,18 @@ reg Sfdisc_t *disc;
 
     /* close the unget stream */
     if (type != SF_CLOSING)
-	(void) sfclose((*_Sfstack) (f, NIL(Sfio_t *)));
+	(void) sfclose((*_Sfstack) (f, NULL));
 
     return 1;
 }
 
-#if __STD_C
-int sfungetc(reg Sfio_t * f, reg int c)
-#else
-int sfungetc(f, c)
-reg Sfio_t *f;			/* push back one byte to this stream */
-reg int c;			/* the value to be pushed back */
-#endif
+/**
+ * @param f push back one byte to this stream
+ * @param c the value to be pushed back
+ */
+int sfungetc(Sfio_t * f, int c)
 {
-    reg Sfio_t *uf;
+    Sfio_t *uf;
 
     SFMTXSTART(f, -1)
 
@@ -65,7 +53,7 @@ reg int c;			/* the value to be pushed back */
 
     /* make a string stream for unget characters */
     if (f->disc != _Sfudisc) {
-	if (!(uf = sfnew(NIL(Sfio_t *), NIL(char *), (size_t) SF_UNBOUND,
+	if (!(uf = sfnew(NULL, NULL, (size_t) SF_UNBOUND,
 			 -1, SF_STRING | SF_READ))) {
 	    c = -1;
 	    goto done;
@@ -79,16 +67,16 @@ reg int c;			/* the value to be pushed back */
 
     /* space for data */
     if (f->next == f->data) {
-	reg uchar *data;
+	uchar *data;
 	if (f->size < 0)
 	    f->size = 0;
-	if (!(data = (uchar *) malloc(f->size + 16))) {
+	if (!(data = malloc(f->size + 16))) {
 	    c = -1;
 	    goto done;
 	}
 	f->flags |= SF_MALLOC;
 	if (f->data)
-	    memcpy((char *) (data + 16), (char *) f->data, f->size);
+	    memcpy(data + 16, f->data, f->size);
 	f->size += 16;
 	f->data = data;
 	f->next = data + 16;
