@@ -73,18 +73,6 @@ void attach_edge_colors(Agraph_t* g, int dim, real *colors){
 
 }
 
-/* SparseMatrix_read_dot:
- * Wrapper for reading dot graph from file
- */
-Agraph_t* 
-SparseMatrix_read_dot(FILE* f)
-{
-    Agraph_t* g;
-    g = agread (f, 0);
-    aginit(g, AGNODE, "nodeinfo", sizeof(Agnodeinfo_t), TRUE);
-    return g;
-}
-
 /* SparseMatrix_import_dot:
  * Assumes g is connected and simple, i.e., we can have a->b and b->a
  * but not a->b and a->b
@@ -277,14 +265,6 @@ done:
   return A;
 }
 
-
-static real dist(int dim, real *x, real *y){
-  int k;
-  real d = 0;
-  for (k = 0; k < dim; k++) d += (x[k] - y[k])*(x[k]-y[k]);
-  return sqrt(d);
-}
-
 /* get spline info */
 int Import_dot_splines(Agraph_t* g, int *ne, char ***xsplines){
   /* get the list of splines for the edges in the order they appear, and store as a list of strings in xspline.
@@ -330,330 +310,6 @@ int Import_dot_splines(Agraph_t* g, int *ne, char ***xsplines){
   return 1;
 }
 
-void edgelist_export(FILE* f, SparseMatrix A, int dim, real *x){
-  int n = A->m, *ia = A->ia, *ja = A->ja;
-  int i, j, len;
-  real max_edge_len, min_edge_len;
-
-  for (i = 0; i < n; i++){
-    for (j = ia[i]; j < ia[i+1]; j++){
-      max_edge_len = MAX(max_edge_len, dist(dim, &x[dim*i], &x[dim*ja[j]]));
-      if (min_edge_len < 0){
-	min_edge_len = dist(dim, &x[dim*i], &x[dim*ja[j]]);
-      } else {
-	min_edge_len = MIN(min_edge_len, dist(dim, &x[dim*i], &x[dim*ja[j]]));
-      }
-    }
-  }
-  /* format:
-     n
-     nz
-     dim
-     x (length n*dim)
-     min_edge_length
-     max_edge_length
-     v1
-     neighbors of v1
-     v2
-     neighbors of v2
-     ...
-  */
-  fprintf(stderr,"writing a total of %d edges\n",A->nz);
-  fwrite(&(A->n), sizeof(int), 1, f);
-  fwrite(&(A->nz), sizeof(int), 1, f);
-  fwrite(&dim, sizeof(int), 1, f);
-  fwrite(x, sizeof(real), dim*n, f);
-  fwrite(&min_edge_len, sizeof(real), 1, f);
-  fwrite(&max_edge_len, sizeof(real), 1, f);
-  for (i = 0; i < n; i++){
-    if (i%1000 == 0) fprintf(stderr,"%6.2f%% done\r", i/(real) n*100);
-    fwrite(&i, sizeof(int), 1, f);
-    len = ia[i+1] - ia[i];
-    fwrite(&len, sizeof(int), 1, f);
-    fwrite(&(ja[ia[i]]), sizeof(int), len, f);
-  }
-}
-
-
-void dump_coordinates(char *name, int n, int dim, real *x){
-  char fn[1000];
-  FILE *fp;
-  int i, k;
-
-  if (!name){
-    name = "";
-  } else {
-    name = strip_dir(name);
-  }
-  
-  strcpy(fn, name);
-  strcat(fn,".x");
-  fp = fopen(fn,"w");
-  fprintf(fp, "%d %d\n",n, dim);
-  for (i = 0; i < n; i++){
-    for (k = 0; k < dim; k++){
-      fprintf(fp,"%f ",x[i*dim+k]);
-    }
-    fprintf(fp,"\n");
-  }
-  fclose(fp);
-
-}
-
-static Agnode_t*
-mkNode (Agraph_t* g, char* name)
-{
-  Agnode_t* n = agnode(g, name, 1);
-  agbindrec(n, "info", sizeof(Agnodeinfo_t), TRUE);
-  return n;
-}
-
-Agraph_t* 
-makeDotGraph (SparseMatrix A, char *name, int dim, real *x, int with_color, int with_label, int  use_matrix_value)
-{
-  Agraph_t* g;
-  Agnode_t* n;
-  Agnode_t* h;
-  Agedge_t* e;
-  int i, j;
-  char buf2[1024];
-  Agsym_t *sym2 = NULL, *sym3 = NULL;
-  int* ia=A->ia;
-  int* ja=A->ja;
-  real* val = (real*)(A->a);
-  Agnode_t** arr = N_NEW (A->m, Agnode_t*);
-  real *color = NULL;
-  char cstring[8];
-  char label_string[1000];
-
-  if (!name){
-    name = "stdin";
-  } else {
-    name = strip_dir(name);
-  }
-
-  if (SparseMatrix_known_undirected(A)){
-    g = agopen ("G", Agundirected, 0);
-  } else {
-    g = agopen ("G", Agdirected, 0);
-  }
-
-  snprintf(label_string, sizeof(label_string), "%s. %d nodes, %d edges.", name,
-           A->m, A->nz);
-
-  if (with_label) agattr(g, AGRAPH, "label", label_string);
-  agattr(g, AGRAPH, "fontcolor", "#808090");
-  if (with_color) agattr(g, AGRAPH, "bgcolor", "black");
-  agattr(g, AGRAPH, "outputorder", "edgesfirst");
-
-  if (A->m > 100) {
-    /* -Estyle=setlinewidth(0.0)' -Eheadclip=false -Etailclip=false -Nstyle=invis*/
-    agattr(g, AGNODE, "style", "invis"); 
-  } else {
-    /*    width=0, height = 0, label="", style=filled*/
-    agattr(g, AGNODE, "shape", "point"); 
-    if (A->m < 50){
-      agattr(g, AGNODE, "width", "0.03"); 
-    } else {
-      agattr(g, AGNODE, "width", "0"); 
-    }
-    agattr(g, AGNODE, "label", ""); 
-    agattr(g, AGNODE, "style", "filled"); 
-    if (with_color) {
-      agattr(g, AGNODE, "color", "#FF0000"); 
-    } else {
-      agattr(g, AGNODE, "color", "#000000"); 
-    }
-  }
-
-  agattr(g, AGEDGE, "headclip", "false"); 
-  agattr(g, AGEDGE, "tailclip", "false"); 
-  if (A->m < 50){
-    agattr(g, AGEDGE, "style", "setlinewidth(2)"); 
-  } else if (A->m < 500){
-    agattr(g, AGEDGE, "style", "setlinewidth(0.5)"); 
-  } else if (A->m < 5000){
-    agattr(g, AGEDGE, "style", "setlinewidth(0.1)"); 
-  } else {
-    agattr(g, AGEDGE, "style", "setlinewidth(0.0)"); 
-  }
-
-  if (with_color) {
-    sym2 = agattr(g, AGEDGE, "color", ""); 
-    sym3 = agattr(g, AGEDGE, "wt", ""); 
-  }
-  for (i = 0; i < A->m; i++) {
-    n = mkNode (g, itos(i).str);
-    ND_id(n) = i;
-    arr[i] = n;
-  }
-
-  if (with_color){
-    real maxdist = 0.;
-    real mindist = 0.;
-    bool first = true;
-    color = malloc(sizeof(real)*A->nz);
-    for (n = agfstnode (g); n; n = agnxtnode (g, n)) {
-      i = ND_id(n);
-      if (A->type != MATRIX_TYPE_REAL || !use_matrix_value){
-	for (j = ia[i]; j < ia[i+1]; j++) {
-	  color[j] = distance(x, dim, i, ja[j]);
-	  if (i != ja[j]){
-	    if (first){
-	      mindist = color[j];
-	      first = false;
-	    } else {
-	      mindist = MIN(mindist, color[j]);
-	    }
-	  }
-	  maxdist = MAX(color[j], maxdist);
-	}
-      } else {
-	for (j = ia[i]; j < ia[i+1]; j++) {
-	  color[j] = fabs(val[j]);
-	  if (i != ja[j]){
-	    if (first){
-	      mindist = color[j];
-	      first = false;
-	    } else {
-	      mindist = MIN(mindist, color[j]);
-	    }
-	  }
-	  maxdist = MAX(color[j], maxdist);
-	}
-      }
-    }
-    for (n = agfstnode (g); n; n = agnxtnode (g, n)) {
-      i = ND_id(n);
-      for (j = ia[i]; j < ia[i+1]; j++) {
-        if (i != ja[j]){
-	  color[j] = ((color[j] - mindist)/MAX(maxdist-mindist, 0.000001));
-        } else {
-          color[j] = 0;
-        }
-      }
-    }
-  }
-
-  for (n = agfstnode (g); n; n = agnxtnode (g, n)) {
-    i = ND_id(n);
-    for (j = ia[i]; j < ia[i+1]; j++) {
-      h = arr [ja[j]];
-      if (val){
-	if (with_color) {
-          if (i != ja[j]){
-            snprintf(buf2, sizeof(buf2), "%s", hue2rgb(.65*color[j], cstring));
-          } else {
-            snprintf(buf2, sizeof(buf2), "#000000");
-          }
-        }
-      } else {
-        if (with_color) {
-          if (i != ja[j]){
-            snprintf(buf2, sizeof(buf2), "%s", hue2rgb(.65*color[j], cstring));
-          } else {
-            snprintf(buf2, sizeof(buf2), "#000000");
-          }
-        }
-     }
-      e = agedge (g, n, h, NULL, 1);
-      if (with_color) {
-	agxset (e, sym2, buf2);
-	snprintf(buf2, sizeof(buf2), "%f", color[j]);
-	agxset (e, sym3, buf2);
-      }
-    }
-  }
-  
-  FREE(color);
-  FREE (arr);
-  return g;
-}
-
-static char *cat_string3(char *s1, char *s2, char *s3, int id){
-  return gv_sprint_or_exit("%s|%s|%s|%d", s1, s2, s3, id);
-}
-
-
-Agraph_t *convert_edge_labels_to_nodes(Agraph_t* g){
-  if (!g) return NULL;
-
-  Agnode_t *n, *newnode;
-  Agraph_t *dg;
-
-  int nnodes;
-
-
-  Agedge_t *ep, *e;
-  int i = 0;
-  Agnode_t **ndmap = NULL;
-  char *s;
-  char *elabel;
-  int id = 0;
-
-  Agsym_t* sym = agattr(g, AGEDGE, "label", NULL);
-
-  dg = agopen("test", g->desc, 0);
-
-  nnodes = agnnodes (g);
-
-  ndmap = malloc(sizeof(Agnode_t *)*nnodes);
-
-  agattr(dg, AGNODE, "label", "\\N"); 
-  agattr(dg, AGNODE, "shape", "ellipse"); 
-  agattr(dg, AGNODE, "width","0.00001");
-  agattr(dg, AGNODE, "height", "0.00001");
-  agattr(dg, AGNODE, "margin","0.");
-  agattr(dg, AGEDGE, "arrowsize", "0.5"); 
-
-  for (n = agfstnode (g); n; n = agnxtnode (g, n)) {
-    newnode = mkNode(dg, agnameof(n));
-    agset(newnode,"shape","box");
-    ndmap[i] = newnode;
-    ND_id(n) = i++;
-  }
-
-  for (n = agfstnode (g); n; n = agnxtnode (g, n)) {
-    for (ep = agfstedge(g, n); ep; ep = agnxtedge(g, ep, n)) {
-      if (agtail(ep) == n && (aghead(ep) != n)) continue;
-      if (sym && (elabel = agxget(ep,sym)) && strcmp(elabel,"") != 0) {
-	s = cat_string3("|edgelabel",agnameof(agtail(ep)), agnameof(aghead(ep)), id++);
-	newnode = mkNode(dg,s);
-	agset(newnode,"label",elabel);
-	agset(newnode,"shape","plaintext");
-	e = agedge(dg, ndmap[ND_id(agtail(ep))], newnode, NULL, 1);
-	agset(e, "arrowsize","0");
-	agedge(dg, newnode, ndmap[ND_id(aghead(ep))], NULL, 1);
-	free(s);
-      } else {
-	agedge(dg, ndmap[ND_id(agtail(ep))], ndmap[ND_id(aghead(ep))], NULL, 1);
-      }
-    }
-  }
-
-  free(ndmap);
-  return dg;
- }
-
-Agraph_t* assign_random_edge_color(Agraph_t* g){
-  char cstring[8];
-  char buf2[1024];
-  Agsym_t *sym2;
-  Agnode_t* n;
-  Agedge_t *ep;
-
-  sym2 = agattr(g, AGEDGE, "color", ""); 
-  for (n = agfstnode (g); n; n = agnxtnode (g, n)) {
-    for (ep = agfstedge(g, n); ep; ep = agnxtedge(g, ep, n)) {
-      snprintf(buf2, sizeof(buf2), "%s", hue2rgb(0.65*drand(), cstring));
-      agxset (ep, sym2, buf2);
-    }
-  }
-
-  return g;
- }
-
-
 static int hex2int(char h){
   if (h >= '0' && h <= '9') return h - '0';
   if (h >= 'a' && h <= 'f') return 10 + h - 'a';
