@@ -94,6 +94,8 @@ static void vml_print_color(GVJ_t * job, gvcolor_t color)
 
 static void vml_grstroke(GVJ_t * job, int filled)
 {
+    (void)filled;
+
     obj_state_t *obj = job->obj;
 
     gvputs(job, "<v:stroke color=\"");
@@ -123,12 +125,12 @@ static void vml_grfill(GVJ_t * job, int filled)
 }
 
 /*  html_string is a modified version of xml_string  */
-char *html_string(char *s)
+static char *html_string(char *s)
 {
     static char *buf = NULL;
-    static int bufsize = 0;
+    static size_t bufsize = 0;
     char *p, *sub, *prev = NULL;
-    int len, pos = 0;
+    size_t len, pos = 0;
     int temp,cnt,remaining=0;
     char workstr[16];
     uint64_t charnum=0;
@@ -204,7 +206,7 @@ char *html_string(char *s)
             sub=&workstr[14];
             len=3; /*  &#  + ;  */
             do {
-              temp=charnum%10;
+              temp=(int)(charnum%10);
               *(sub--)=(char)((int)'0'+ temp);
               charnum/=10;
               len++;
@@ -253,8 +255,8 @@ static void vml_begin_graph(GVJ_t * job)
     obj_state_t *obj = job->obj;
     char *name;
 
-    graphHeight =(int)(job->bb.UR.y - job->bb.LL.y);
-    graphWidth  =(int)(job->bb.UR.x - job->bb.LL.x);
+    graphHeight = (unsigned)(job->bb.UR.y - job->bb.LL.y);
+    graphWidth  = (unsigned)(job->bb.UR.x - job->bb.LL.x);
 
     gvputs(job, "<HEAD>");
     gvputs(job, "<META http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\">\n");
@@ -316,15 +318,15 @@ static void vml_begin_graph(GVJ_t * job)
     gvputs(job, "<BODY onload='browsercheck();'>\n");
     /* add 10pt pad to the bottom of the graph */
     gvputs(job, "<DIV id='_VML1_' style=\"position:relative; display:inline; visibility:hidden");
-    gvprintf(job, " width: %dpt; height: %dpt\">\n", graphWidth, 10+graphHeight);
+    gvprintf(job, " width: %upt; height: %upt\">\n", graphWidth, 10+graphHeight);
     gvputs(job, "<STYLE>\n");
     gvputs(job, "v\\:* { behavior: url(#default#VML);display:inline-block}\n"); 
     gvputs(job, "</STYLE>\n"); 
     gvputs(job, "<xml:namespace ns=\"urn:schemas-microsoft-com:vml\" prefix=\"v\" />\n"); 
 
     gvputs(job, " <v:group style=\"position:relative; ");
-    gvprintf(job, " width: %dpt; height: %dpt\"", graphWidth, graphHeight);
-    gvprintf(job, " coordorigin=\"0,0\" coordsize=\"%d,%d\" >", graphWidth, graphHeight);
+    gvprintf(job, " width: %upt; height: %upt\"", graphWidth, graphHeight);
+    gvprintf(job, " coordorigin=\"0,0\" coordsize=\"%u,%u\" >", graphWidth, graphHeight);
 }
 
 static void vml_end_graph(GVJ_t * job)
@@ -349,6 +351,8 @@ static void vml_end_graph(GVJ_t * job)
 static void
 vml_begin_anchor(GVJ_t * job, char *href, char *tooltip, char *target, char *id)
 {
+    (void)id;
+
     gvputs(job, "<a");
     if (href && href[0])
 	gvprintf(job, " href=\"%s\"", html_string(href));
@@ -465,8 +469,11 @@ static void
 vml_bezier(GVJ_t * job, pointf * A, int n, int arrow_at_start,
 	      int arrow_at_end, int filled)
 {
+    (void)arrow_at_start;
+    (void)arrow_at_end;
+
     gvputs(job, " <v:shape style=\"position:absolute; ");
-    gvprintf(job, " width: %d; height: %d\"", graphWidth, graphHeight);
+    gvprintf(job, " width: %u; height: %u\"", graphWidth, graphHeight);
 
     vml_grfill(job, filled);
     gvputs(job, " >");
@@ -482,7 +489,7 @@ static void vml_polygon(GVJ_t * job, pointf * A, int n, int filled)
     double px,py;
 
     gvputs(job, " <v:shape style=\"position:absolute; ");
-    gvprintf(job, " width: %d; height: %d\"", graphWidth, graphHeight);
+    gvprintf(job, " width: %u; height: %u\"", graphWidth, graphHeight);
     vml_grfill(job, filled);
     gvputs(job, " >");
     vml_grstroke(job, filled);
@@ -508,7 +515,7 @@ static void vml_polyline(GVJ_t * job, pointf * A, int n)
     int i;
 
     gvputs(job, " <v:shape style=\"position:absolute; ");
-    gvprintf(job, " width: %d; height: %d\" filled=\"false\">", graphWidth, graphHeight);
+    gvprintf(job, " width: %u; height: %u\" filled=\"false\">", graphWidth, graphHeight);
     gvputs(job, "<v:path v=\"");
     for (i = 0; i < n; i++)
     {
